@@ -1,6 +1,6 @@
 package ElasticSearch::Transport;
 {
-  $ElasticSearch::Transport::VERSION = '0.42';
+  $ElasticSearch::Transport::VERSION = '0.43';
 }
 
 use strict;
@@ -17,6 +17,7 @@ our %Transport = (
     'httptiny' => 'ElasticSearch::Transport::HTTPTiny',
     'curl'     => 'ElasticSearch::Transport::Curl',
     'aehttp'   => 'ElasticSearch::Transport::AEHTTP',
+    'aecurl'     => 'ElasticSearch::Transport::AECurl',
 );
 
 #===================================
@@ -567,6 +568,11 @@ to communicate using HTTP. See L<ElasticSearch::Transport::Curl>
 Uses L<AnyEvent::HTTP> to communicate asynchronously using HTTP.
 See L<ElasticSearch::Transport::AEHTTP>
 
+=item * C<aecurl>
+
+Uses L<AnyEvent::Curl::Multi> (and thus L<libcurl|http://curl.haxx.se/libcurl/>)
+to communicate asynchronously using HTTP. See L<ElasticSearch::Transport::AECurl>
+
 =item * C<thrift>
 
 Uses C<thrift>  to communicate using a compact binary protocol over sockets.
@@ -719,6 +725,8 @@ You can register your Transport backend as follows:
 
 =item * L<ElasticSearch::Transport::AEHTTP>
 
+=item * L<ElasticSearch::Transport::AECurl>
+
 =item * L<ElasticSearch::Transport::Thrift>
 
 =back
