@@ -18,4 +18,9 @@ is $es->cluster_state->{metadata}{indices}{'es_test_2'}{settings}
 throws_ok { $es->index_status( index => 'foo' ) }
 qr/ElasticSearch::Error::Missing/, ' - index missing';
 
+ok $r= $es->index_status( index => 'es_test_1', recovery => 1, snapshot => 1 )
+    ->{indices}{es_test_1}{shards}{0}, ' - recovery and snapshot';
+
+ok $r->[0]{peer_recovery}||$r->[0]{gateway_recovery},    ' - recovery';
+
 1;
